import type { CreateTRPCClientOptions } from '@trpc/client';
import type { AnyMutationProcedure, AnyProcedure, AnyQueryProcedure, AnySubscriptionProcedure, AnyRouter, ProcedureArgs, ProcedureRouterRecord, inferProcedureOutput } from '@trpc/server';
import type { inferObservableValue } from '@trpc/server/observable';
import type { Atom, Getter, WritableAtom } from 'jotai/vanilla';
type ValueOrGetter<T> = T | ((get: Getter) => T);
type QueryResolver<TProcedure extends AnyProcedure, TClient> = (getInput: ValueOrGetter<ProcedureArgs<TProcedure['_def']>[0]>, getOptions?: ValueOrGetter<ProcedureArgs<TProcedure['_def']>[1]>, getClient?: (get: Getter) => TClient) => Atom<Promise<inferProcedureOutput<TProcedure>>>;
type MutationResolver<TProcedure extends AnyProcedure, TClient> = (getClient?: (get: Getter) => TClient) => WritableAtom<inferProcedureOutput<TProcedure> | null, [
    ProcedureArgs<TProcedure['_def']>
], Promise<inferProcedureOutput<TProcedure>>>;
type SubscriptionResolver<TProcedure extends AnyProcedure, TClient> = (getInput: ValueOrGetter<ProcedureArgs<TProcedure['_def']>[0]>, getOptions?: ValueOrGetter<ProcedureArgs<TProcedure['_def']>[1]>, getClient?: (get: Getter) => TClient) => Atom<inferObservableValue<inferProcedureOutput<TProcedure>>>;
type DecorateProcedure<TProcedure extends AnyProcedure, TClient> = TProcedure extends AnyQueryProcedure ? {
    atomWithQuery: QueryResolver<TProcedure, TClient>;
} : TProcedure extends AnyMutationProcedure ? {
    atomWithMutation: MutationResolver<TProcedure, TClient>;
} : TProcedure extends AnySubscriptionProcedure ? {
    atomWithSubscription: SubscriptionResolver<TProcedure, TClient>;
} : never;
type DecoratedProcedureRecord<TProcedures extends ProcedureRouterRecord, TClient> = {
    [TKey in keyof TProcedures]: TProcedures[TKey] extends AnyRouter ? DecoratedProcedureRecord<TProcedures[TKey]['_def']['record'], TClient> : TProcedures[TKey] extends AnyProcedure ? DecorateProcedure<TProcedures[TKey], TClient> : never;
};
export declare function createTRPCJotai<TRouter extends AnyRouter>(opts: CreateTRPCClientOptions<TRouter>): DecoratedProcedureRecord<TRouter["_def"]["record"], import("@trpc/client").CreateTRPCProxyClient<TRouter>>;
export {};
